@@ -179,5 +179,47 @@ class NodeIndex {
   public Map<String, Set<String>> getRelaysByVersion() {
     return this.relaysByVersion;
   }
+
+  private Map<String, Set<String>> bridgesByVersion;
+
+  public void setBridgesByVersion(Map<String, Set<String>> bridgesByVersion) {
+    this.bridgesByVersion = bridgesByVersion;
+  }
+
+  public Map<String, Set<String>> getBridgesByVersion() {
+    return this.bridgesByVersion;
+  }
+
+  private Map<String, Set<String>> relaysByHostName;
+
+  public void setRelaysByHostName(Map<String, Set<String>> relaysByHostName) {
+    this.relaysByHostName = relaysByHostName;
+  }
+
+  public Map<String, Set<String>> getRelaysByHostName() {
+    return this.relaysByHostName;
+  }
+
+  private Map<Boolean, Set<String>> relaysByRecommendedVersion;
+
+  public void setRelaysByRecommendedVersion(
+      Map<Boolean, Set<String>> relaysByRecommendedVersion) {
+    this.relaysByRecommendedVersion = relaysByRecommendedVersion;
+  }
+
+  public Map<Boolean, Set<String>> getRelaysByRecommendedVersion() {
+    return this.relaysByRecommendedVersion;
+  }
+
+  private Map<Boolean, Set<String>> bridgesByRecommendedVersion;
+
+  public void setBridgesByRecommendedVersion(
+      Map<Boolean, Set<String>> bridgesByRecommendedVersion) {
+    this.bridgesByRecommendedVersion = bridgesByRecommendedVersion;
+  }
+
+  public Map<Boolean, Set<String>> getBridgesByRecommendedVersion() {
+    return this.bridgesByRecommendedVersion;
+  }
 }
 
